Package: annotationTools
Version: 1.84.0
Date: 2020-03-27
Title: Annotate microarrays and perform cross-species gene expression
        analyses using flat file databases
Author: Alexandre Kuhn <alexandre.m.kuhn@gmail.com>
Maintainer: Alexandre Kuhn <alexandre.m.kuhn@gmail.com>
Imports: Biobase, stats
Suggests: BiocStyle
Description: Functions to annotate microarrays, find orthologs, and integrate heterogeneous gene expression profiles using annotation and other molecular biology information available as flat file database (plain text files).
biocViews: Microarray, Annotation
License: GPL
ZipData: no
git_url: https://git.bioconductor.org/packages/annotationTools
git_branch: RELEASE_3_22
git_last_commit: 906b275
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 02:30:28 UTC; biocbuild
