\name{homologene_part}
\docType{data}
\alias{homologene_part}
\title{Example HomoloGene file}
\description{Truncated HomoloGene database file.
}
\format{A table containing 3 homology clusters defined by HomoloGene.}
\source{\url{http://www.ncbi.nlm.nih.gov/HomoloGene}}
\keyword{datasets}
